#
# spec file for package enigma
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           enigma
Version:        1.30
Release:        1.11
Summary:        An Excellent Oxyd Clone
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            http://www.nongnu.org/enigma/
Source0:        https://github.com/Enigma-Game/Enigma/releases/download/%{version}/Enigma-%{version}-src.tar.gz
Source1:        %{name}-help.desktop
Source2:        %{name}.desktop
Source3:        %{name}.png
Source4:        %{name}-help.png
Source5:        enigma_de.pdf
Source6:        french_russian.tar.bz2
BuildRequires:  ImageMagick
BuildRequires:  enet-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-tools
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xerces-c)

%description
Enigma is similar to the well known game Oxyd.

%prep
%setup -q

%build
%configure \
    --with-system-enet
make %{?_smp_mflags}

%install
%make_install
install -D -m 644 %{_sourcedir}/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -m 644 %{_sourcedir}/%{name}-help.png %{buildroot}%{_datadir}/pixmaps/%{name}-help.png
%suse_update_desktop_file -i %{name}
%suse_update_desktop_file -i %{name}-help

mkdir -p %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/enigma/ %{buildroot}%{_defaultdocdir}/%{name}
install -m 644 %{SOURCE5} %{buildroot}%{_defaultdocdir}/%{name}
tar -xjf %{SOURCE6} -C %{buildroot}%{_defaultdocdir}/%{name}
%png_fix_dir %{buildroot}/%{_datadir}/enigma
%fdupes %{buildroot}%{_datadir}

%files
%doc %{_defaultdocdir}/%{name}
%{_bindir}/enigma
%{_mandir}/man6/enigma.6%{?ext_man}
%{_datadir}/enigma/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-help.desktop
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/pixmaps/%{name}-help.png
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Sat Aug 28 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.30
  User-Visible Changes
  * New translations: Bosnian, Chinese, Japanese, Norwegian, and
    Slovene.
  * New game objects: forward floors, glass marble, st_inkwell,
    st_portal_glass, st_document, st_pebble.
  * 116 new main-pack levels (now a total of 1100 main-pack levels,
    plus 22 tutorials, 1119 sokoballs, 95 pentominoes, 268 dejavus,
    and 2 training levels; altogether 2606).
  * window can be resized.
  * middle mouse key can be customized.
  Internal changes
  * switched from SDL 1.2 to SDL 2.0 .
  * several bug fixes.
  * support for additional tilesets.
  * use of tinygettext instead of gettext.
  List of shortcomings / known bugs
  * Rescaling the application window introduces graphical
    artifacts: Better use fixed window sizes for now.
  * Not all fullscreen modes are available yet, in particular no
    vertical screen modes. If you use a vertical screen, please
    use Enigma in windowed mode.
- Use github source url
- Remove compat stuff for old distributions
* Fri Jul 13 2018 mardnh@gmx.de
- Update to version 1.21
- Drop not longer needed patches
- Use pgkconfig style dependencies
- Specfile cleanup
* Fri Nov 29 2013 pgajdos@suse.com
- use png_fix_dir macro [bnc#852862]
* Mon Jan 21 2013 joop.boonen@opensuse.org
- Created a png > 1.4 patch
* Wed May  2 2012 joop.boonen@opensuse.org
- Added missing BuildRequires automake
- Added gcc 4.7 patch
- Passed the spec file through spec cleaner
* Sat Nov 19 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Nov 18 2011 jreidinger@suse.com
- update includes.patch to fix issue with new gcc for 12.1
* Fri Jan  8 2010 dnh@opensuse.org
- fixes for 11.2 / x86_64 (includes.patch, xerces3.patch)
* Wed Oct 14 2009 prusnak@suse.cz
- fix strchr call (constchar.patch)
- fix missing includes (includes.patch)
- cleaned up spec file
* Fri May  1 2009 dominique-obs@leuenberger.net
- Added patch to compile against xerces 3 (openSUSE > 11.1)
* Tue May  6 2008 aj@suse.de
- Fix missing return value.
- Fix some rpmlint warnings: Remove handling of version <= 9.3,
  run fdupes, fix build requires, bzip sources.
* Mon Dec  3 2007 ro@suse.de
- fix build with gcc-4.3
* Mon Aug  6 2007 sndirsch@suse.de
- updated to release 1.01
  * Enigma 1.01 is a bug fix and level addition release with some
    small feature additions.
* Mon Jul  9 2007 sndirsch@suse.de
- fixed BuildRequires for openSUSE > 10.2
* Sun May  6 2007 sndirsch@suse.de
- added french and russian manual
* Thu Jan 25 2007 sndirsch@suse.de
- fixed "comparison with string literal" warning
* Fri Jan  5 2007 sndirsch@suse.de
- updated to release 1.00
  * 200++ new levels (now more than 970 in total)
  * New levelpack sorting
  * Drop & play of new levels and new levelpacks
  * Level inspector for ratings and statistics about levels
  * Screenshot viewer
  * Personal annotations and rating of levels
  * Translations of level titles and documents
  * New languages: Swedish, Russian, Hungarian, Portuguese
  * Countless smaller enhancements
* Sat Oct 28 2006 sndirsch@suse.de
- fixed startup (Bug #216018)
* Fri Sep  8 2006 sndirsch@suse.de
- fixed build on SUSE 9.3
* Wed Jun 14 2006 dmueller@suse.de
- build parallel
* Tue Jun 13 2006 sndirsch@suse.de
- fixed wrong function declaration (Bug #183695)
* Sat Apr 15 2006 sndirsch@suse.de
- added german manual (PDF)
* Thu Feb 16 2006 stbinner@suse.de
- add GenericName to .desktop file
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 10 2005 sndirsch@suse.de
- docs.diff:
  * fixes broken images in documentation (#133229)
* Tue Oct 18 2005 sndirsch@suse.de
- removed extra qualifications (fatal error for gcc 4.1)
* Thu Jul 28 2005 sndirsch@suse.de
- added libmikmod to #neededforbuild
* Fri Jul 22 2005 sndirsch@suse.de
- added SDL_mixer-devel to #neededforbuild
* Fri Jun 10 2005 sndirsch@suse.de
- updated to release 0.92
  * Added Spanish translation
  * Fixed bug: ice is now working
  * A few smaller bug fixes
* Thu May 12 2005 sndirsch@suse.de
- use norootforbuild
* Thu May  5 2005 sndirsch@suse.de
- updated to release 0.91
- adjusted enigma-0.91.diff
* Sat Apr  2 2005 coolo@suse.de
- fix C++
* Thu Jan 27 2005 sndirsch@suse.de
- updated to release 0.90 RC1
* Fri Nov 12 2004 sndirsch@suse.de
- updated to release 0.90-beta
* Mon Oct 13 2003 sndirsch@suse.de
- updated to release 0.81
- added desktop file/pixmap for new Game Manual
* Tue Sep 30 2003 sndirsch@suse.de
- updated to release 0.80-beta
  * Time game
  * Easy / difficult game mode
  * Sokoban mode
  * Game manual
  * More than 300 new levels (now more than 550 in total)
  * (partially working) Oxyd level importer
  * Better soft scrolling
  * Countless new game elements: turnstiles, volcanos, warp tunnels,
    land-mines, jump pads, rotors, ...
  * Reduced memory footprint
- removed assert patch (already included upstream)
- use new official desktop icon from package now
* Sat Aug 30 2003 sndirsch@suse.de
- added desktop icon
* Fri Aug  8 2003 sndirsch@suse.de
- added desktop file
* Wed Jul 30 2003 meissner@suse.de
- run autoreconf to make it work on ppc64
* Tue Feb 25 2003 ro@suse.de
- include assert where needed
* Mon Feb 17 2003 sndirsch@suse.de
- updated to release 0.70
  * Speed improvements
  * Stereo sound
  * More than 70 new levels
  * Much better mouse controls
  * Support for Oxyd's original sounds (see README)
  * New game objects: Rubber bands, scissors, worm holes
* Sun Dec 29 2002 sndirsch@suse.de
- updated to release 0.60
* Mon Aug 26 2002 sndirsch@suse.de
- added documentation
* Fri Aug 16 2002 sndirsch@suse.de
- updated to release 0.50
* Fri Jul 19 2002 sndirsch@suse.de
- added 'smpeg' to #neededforbuild
* Tue May 21 2002 sndirsch@suse.de
- created package
